#' @importFrom htmlwidgets JS
#' @export
htmlwidgets::JS

#' @importFrom htmlwidgets onRender
#' @export
htmlwidgets::onRender

#' @importFrom magrittr %>%
#' @export
magrittr::`%>%`

#' @importFrom magrittr %<>%
#' @export
magrittr::`%<>%`
